@@ -1,6 +1,8 @@
 # -*- coding:utf-8 -*-
-from .winConst import *
-from .myctypes import *
+from ctypes import (
+    c_int,
+    c_ushort
+)
 from .wkeStruct import wkeProxy
 
 class Proxy():
